UnixSocket

Enum UnixSocket 

#[non_exhaustive]
pub enum UnixSocket { File(PathBuf), Abstract(OsString), Dir(PathBuf), TmpDir(PathBuf), }
A Unix domain socket path in a D-Bus address.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


File(PathBuf)

A path to a unix domain socket on the filesystem.



Abstract(OsString)

An abstract unix domain socket name.



Dir(PathBuf)

A listenable address using the specified path, in which a socket file with a random file name starting with ‘dbus-’ will be created by the server. See UNIX domain socket address reference documentation.

This address is mostly relevant to server (typically bus broker) implementations.



TmpDir(PathBuf)

The same as UnixDir, except that on platforms with abstract sockets, the server may attempt to create an abstract socket whose name starts with this directory instead of a path-based socket.

This address is mostly relevant to server (typically bus broker) implementations.